@@ -49,7 +49,7 @@ class CSVReader(FileHandler):
 
                 if handler and buffer <= len(data):
                     df = self.__to_df(data)
-                    handler(df, row_num - len(df) + 1, row_num)
+                    handler(self.file_path, df, row_num - len(df) + 1, row_num)
                     data.clear()
                     data.append(header)
 
@@ -64,7 +64,7 @@ class CSVReader(FileHandler):
 
         if not df.empty and handler:
             row_num -= 1
-            handler(df, row_num - len(df) + 1, row_num)
+            handler(self.file_path, df, row_num - len(df) + 1, row_num)
         elif not handler:
             return df
 
